'use strict';
function hasKey(obj, key) {
    return key in obj;
}
var getRate = function (_a) {
    var base = _a.base, rates = _a.rates, from = _a.from, to = _a.to;
    if (hasKey(rates, from) && hasKey(rates, to)) {
        // If `from` equals `base`, return the basic exchange rate for the `to` currency
        if (from === base) {
            return rates[to];
        }
        // If `to` equals `base`, return the basic inverse rate of the `from` currency
        if (to === base) {
            return 1 / rates[from];
        }
        /**
    Otherwise, return the `to` rate multipled by the inverse of the `from` rate to get the
    relative exchange rate between the two currencies
    */
        return rates[to] * (1 / rates[from]);
    }
    throw new Error('Rates do not contain either `from` or `to` currency!');
};
var Cashify = /** @class */ (function () {
    function Cashify(_a) {
        var base = _a.base, rates = _a.rates;
        this.options = {
            base: base,
            rates: rates
        };
    }
    /**
    * @param {number} amount Amount of money you want to convert
    * @param {object} options Conversion options
    * @param {string} options.from Currency from which you want to convert
    * @param {string} options.to Currency to which you want to convert
    * @return {number} Conversion result
    */
    Cashify.prototype.convert = function (amount, _a) {
        var from = _a.from, to = _a.to;
        var _b = this.options, base = _b.base, rates = _b.rates;
        return amount * getRate({ base: base, rates: rates, from: from, to: to });
    };
    return Cashify;
}());
export default Cashify;
